@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2016 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2016 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2017 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2017 GNU Solidario <health@gnusolidario.org>
 #
 #    Copyright (C) 2011  Adrián Bernardi, Mario Puntin (health_invoice)
 #
@@ -77,6 +77,9 @@ class HealthService(ModelSQL, ModelView):
                 'draft')}
             })
 
+        cls._order.insert(0, ('state', 'ASC'))
+        cls._order.insert(1, ('name', 'DESC'))
+
     @staticmethod
     def default_state():
         return 'draft'
@@ -135,23 +138,19 @@ class HealthServiceLine(ModelSQL, ModelView):
         if self.product:
             self.desc = self.product.name
 
-    @classmethod
-    def write(cls, lines, vals):
-        """Do not allow new service lines for invoiced items"""
-        if lines[0].name.state == 'invoiced':
-            cls.raise_user_error(
-                "This service has been invoiced.\n"
-                "You can no longer modify service lines.")
-        return super(HealthServiceLine, cls).write(lines, vals)
 
-    #@classmethod
-    #def delete(cls, lines):
-        #"""Prohibit deleting service lines for invoiced items """
-        #if lines[0].name.state == 'invoiced':
-            #cls.raise_user_error(
-                #"This service has been invoiced.\n"
-                #"You can no longer modify service lines.")
-        #return super(HealthServiceLine, cls).delete(lines)
+    @classmethod
+    def validate(cls, services):
+        super(HealthServiceLine, cls).validate(services)
+        for service in services:
+            service.validate_invoice_status()
+
+    def validate_invoice_status(self):
+        if (self.name):
+            if (self.name.state == 'invoiced'):
+                self.raise_user_error(
+                    "This service has been invoiced.\n"
+                    "You can no longer modify service lines.")
 
 
 """ Add Prescription order charges to service model """
@@ -168,6 +167,7 @@ class PatientPrescriptionOrder(ModelSQL, ModelView):
 
     @classmethod
     def __setup__(cls):
+        super(PatientPrescriptionOrder, cls).__setup__()
         cls._buttons.update({
             'update_service': {
                 'readonly': Equal(Eval('state'), 'done'),
